#ifndef DISPLAYER_H
#define DISPLAYER_H

#include "opencv2/core/core.hpp"
#include "opencv2/features2d/features2d.hpp"
#include "FeatureSystem.h"

using namespace cv;

/**
 * Helper class that handles displaying images, keypoints and matches on the screen
 * using OpenCV's graphics capabilities
 */
class Displayer {
public:
	void displayTwoImgs(const Mat& img1, const Mat& img2);
	
	void displayKeypoints(const Mat& img1, const std::vector<KeyPoint>& img1Keypoints,
						const Mat& img2, const std::vector<KeyPoint>& img2Keypoints, int color);

	void displayMatches(const Mat& img1, const Mat& img2, const vector<Match>& matches, int color);

	void displayMatches(const Mat& img1, const std::vector<KeyPoint>& img1Keypoints,
						const Mat& img2, const std::vector<KeyPoint>& img2Keypoints,
						const vector<DMatch>& matches);

	void displayMatches(const Mat& img1, const Mat& img2, const vector<Match>& matches,
						const std::vector<double>& supportTable, double median, double medianScale, int color);

	void displayMSERs(const Mat& img1, const Mat& img2, const std::vector<std::vector<Point>>& msers1,
					  const std::vector<std::vector<Point>>& msers2);
private:
	Mat mergeTwoImgs(const Mat& img1, const Mat& img2);
	void drawKeypoints(const Mat& img1, const std::vector<KeyPoint>& keypoints, Mat& outputImage, int color);
	void displayMat(const Mat& img);
	void displayMatch(Mat& correspond, const Match& match, int firstImageWidth, CvScalar color);
};
#endif