#include "FileFinder.h"
#include <Windows.h>
#include <iostream>
#include <string>

/**
 * From the given folder path, converts it from a relative path to a full path if necessary
 */
string FileFinder::getRootFolderPath(char* folderPath) {
	string rootFolder;
	if (strstr(folderPath, "..\\") != NULL) {
		// relative path
		const int BUFFER_SIZE = 255;
		char* relative = folderPath;
		char buffer[BUFFER_SIZE];
		_fullpath(buffer, relative, BUFFER_SIZE);
		rootFolder = buffer;
	}
	else {
		rootFolder = folderPath;
	}
	return rootFolder;
}

/**
 * Windows specific implementation of getting all the image files
 * Stores them all in a map of folder name (landmark) to image file paths
 */
void FileFinder::recurseTree(fileContainer& imageFiles, const char* rootFolder) {
	WIN32_FIND_DATA ffd;
	HANDLE hFind;
	string folder = rootFolder;
	folder += "\\*";
	hFind = FindFirstFile(folder.c_str(), &ffd);

	if (hFind == INVALID_HANDLE_VALUE) {
		return;
	}

	do {
		// Ignore '.' and '..'
		if (strcmp(ffd.cFileName, ".") != 0 && strcmp(ffd.cFileName, "..") != 0) {
			string filePath = rootFolder;
			filePath += "\\";
			filePath += ffd.cFileName;

			if (ffd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) {
				// It's a folder
				recurseTree(imageFiles, filePath.c_str());
			}
			else {	
				// Extract folder name from path
				string folder = rootFolder;
				size_t found = folder.find_last_of("/\\");
				imageFiles[folder.substr(found + 1)].push_back(filePath);
			}
		}
	}
	while (FindNextFile(hFind, &ffd) != 0);
}

/**
 * Convenience method for printing the file paths in the container
 */
void FileFinder::printFiles(fileContainer& imageFiles) {
	fileContainer::iterator iter;
	for (iter = imageFiles.begin(); iter != imageFiles.end(); ++iter) {
		cout << "Image paths in landmark: " << iter->first.c_str() << endl;
		cout << "-------------------------" << endl;

		for (size_t i = 0; i < iter->second.size(); ++i) {
			cout << iter->second[i].c_str() << endl;
		}

		cout << endl;
	}
}