#include "ImageFile.h"
#include <sstream>

ImageFile::ImageFile() {
	isNull = true;
}

/**
 * From the given path, stores the image name
 */
string ImageFile::extractImageName(string path) {
	path = path.substr(path.find_last_of("\\") + 1);
	return path.substr(0, path.find_last_of("."));
}

/**
 * Marks this image as "initialized" by storing its landmark and image name
 */
void ImageFile::initialize(string landmarkName_, string filePath_) {
	landmarkName = landmarkName_;
	imageName = extractImageName(filePath_);
	isNull = false;
}

/**
 * Returns if this image is initialized or not
 */
const bool ImageFile::isNULL() const {
	return isNull;
}

string ImageFile::getDisplayName() {
	stringstream ss;
	ss << landmarkName << "[" << imageName << "]";
	return ss.str();
}

/**
 * Displays all the information stored in this image
 */
string ImageFile::toString() {
	stringstream ss;
	ss << getDisplayName();

	for (int i = 0; i < FeatureSystem::COUNT; ++i) {
		if (keypoints[i].size() > 0) {
			ss << " - " << FeatureSystem::getSystemName(i) << ": " << keypoints[i].size();
		}
	}
	return ss.str();
}