#include "MSER.h"
#include "opencv2/imgproc/imgproc.hpp"

// Starting static parameters
int MserSystem::BLUR_SIZE = 7;
double MserSystem::SIGMA = 1.0;

MserSystem::MserSystem(bool blurFirst)
: blurFirst(blurFirst) {}

/**
 * Outputs the MSER regions of the given image, as a vector of contours
 */
void MserSystem::findContours(const cv::Mat& image, std::vector<std::vector<Point>>& contours) {
	MSER detector;

	if (blurFirst) {
		// First blurs the image to remove noise
		cv::Mat blurredImage;
		cv::GaussianBlur(image, blurredImage, Size(BLUR_SIZE,BLUR_SIZE), SIGMA);
		detector(blurredImage, contours);
	}
	else {
		detector(image, contours);
	}
}