#include "ResultsWriter.h"

#include <fstream>
#include <ctime>
#include <direct.h>

ResultsWriter::ResultsWriter() {
	// Don't make a folder for results
}

ResultsWriter::ResultsWriter(string outputFolder_) {
	// Append the current date and time to outputFolder
	time_t rawtime;	
	char buffer [80];

	time ( &rawtime );
	strftime (buffer,80,"%Y_%m_%d_%H-%M-%S", localtime(&rawtime));

	string dateTime = buffer;
	dateTime += "\\";
	outputFolder = outputFolder_ + dateTime;

	// make the root folder as well as the timestamped folder
	_mkdir(outputFolder_.c_str());
	_mkdir(outputFolder.c_str());
}

/**
 * When starting a new landmark, store its name
 * It will be used as the output file name
 */
void ResultsWriter::setCurrentLandmark(string landmark) {
	currentLandmark = landmark;
	currentLandmark += ".csv";
}

/**
 * Outputs the current feature system being compared
 */
void ResultsWriter::setCurrentSystem(string featureSystem) {
	ss << featureSystem << ",";
}

/**
 * Outputs the table header of all the images about to be compared
 */
void ResultsWriter::setImagesCompared(const vector<string>& images) {
	vector<string>::const_iterator iter, last;
	for (iter = images.begin(), last = --images.end(); iter != last; ++iter) {
		ss << *iter << ",";
	}
	ss << *last << "\n";
}

/**
 * Outputs the current image that is being compared
 * It is the first item in a row of the table
 */
void ResultsWriter::setCurrentImage(string image) {
	ss << image << ",";
}

/**
 * Outputs if the comparison was a match or not
 */
void ResultsWriter::recordResult(bool result) {
	ss << (result ? "1" : "0") << ",";
}

/**
 * Undoes the last result recorded
 */
void ResultsWriter::undoResult() {
	const int RESULTSIZE = 2;	// a number followed by a comma
	string currentResult = ss.str();
	emptystream();
	ss << currentResult.substr(0, currentResult.size() - RESULTSIZE);		// Chop off last result and put back in ss
}

/**
 * This row of the table is done
 */
void ResultsWriter::finishImageComparison() {
	ss << "\n";
}

/**
 * Appends the current results to the result file
 */
void ResultsWriter::finishSystem() {
	ofstream file;
	file.open(outputFolder + currentLandmark, ios_base::app);

	// Dump and empty the stringstream
	file << ss.str();
	emptystream();
	file.close();
}

void ResultsWriter::emptystream() {	
	ss.str("");
	ss.clear();		// reset any error flag
}