#include <string.h>
#include <iostream>

#include "opencv2/core/core.hpp"
#include "opencv2/highgui/highgui.hpp"

#include "FileFinder.h"
#include "Tester.h"

// If should print the list of landmark image files
#define PRINT_LANDMARKS 0

// If should scroll through displaying the landmarks with a mouse click
#define SCROLL_LANDMARKS 0

using namespace std;
using namespace cv;

const string window = "Current Image";
fileContainer::iterator beginOfContainer, currentLandmark, endOfContainer;
size_t currentImageIndex = 0;

void displayCurrentImage() {
	Mat currentImage = imread(currentLandmark->second[currentImageIndex], CV_LOAD_IMAGE_GRAYSCALE);
	imshow(window, currentImage);
}

/**
 * Debugging code for displaying each image whenever a mouse click occurs
 * Loops through all the images
 */
void onMouseClick(int evnt, int x, int y, int flags, void* data) {
	if (evnt == CV_EVENT_LBUTTONUP) {
		if (currentLandmark != endOfContainer) {
			if (currentImageIndex + 1 >= currentLandmark->second.size()) {
				++currentLandmark;
				currentImageIndex = 0;
				if (currentLandmark == endOfContainer) {
					return;
				}
			}
			else {
				++currentImageIndex;
			}
			displayCurrentImage();
		}
		else {
			currentLandmark = beginOfContainer;
		}
	}
}

int main(int argc, char** argv) {
	if (argc != 2) {
		cout << "Incorrect parameters, please enter a image data set folder " << endl;
		return -1;
	}

	FileFinder fileFinder;
	Tester tester;
	fileContainer imageFiles;
	string& rootFolder = fileFinder.getRootFolderPath(argv[1]);

	// Get all the image and landmark names
	cout << "Using data set folder: " << rootFolder.c_str() << endl;
	fileFinder.recurseTree(imageFiles, rootFolder.c_str());

	if (PRINT_LANDMARKS) {
		// Debug code to print all the file names
		fileFinder.printFiles(imageFiles);
	}

	if (SCROLL_LANDMARKS) {
		// Debug code to scroll through all the images by clicking the mouse
		namedWindow(window);
		setMouseCallback(window, onMouseClick);
		beginOfContainer = imageFiles.begin();
		endOfContainer = imageFiles.end();
		currentLandmark = beginOfContainer;
		currentImageIndex = 0;

		displayCurrentImage();
	}

	// Execute the actual tests
	tester.run(imageFiles);

	waitKey();

	return 0;
}